<?php
/*
File: inc/functions.php
Description: Plugin functions
Plugin: Smart Adv
Author: Alessio Marzo
*/


// INCLUDE MEGA-FUNCTIONS FRAMEWORK
require_once(SA_DIR.'inc/mega-functions.php');


// Tooltips injection
add_filter('the_content','sa_add_toolips_to_content');

function sa_add_toolips_to_content($content) {
	
	$tooltips_activation = get_post_meta( get_the_id(), 'sa_tt_activation', true );
	
	if($tooltips_activation == 1 || $tooltips_activation == 2) {
		
		// Check Global Activation
		if($tooltips_activation == 2 && get_option('sa_opt_tt_activation') != 'ON') {
			return $content;
		}
		
		$keys = get_terms('advkeys');
		$advertises_html = ''; 
		
		foreach($keys as $key) {
			
			
			if (preg_match("/".$key->name."/i", $content)) { // Check if the key exists in the content
			
							
				// Query ADVs by tag
				$args = array(
				   'post_type' => 'advertises',
				   'tax_query' => array(
					  array(
						 'taxonomy' => 'advkeys', 
						 'field' => 'slug',
						 'terms' => array($key->slug)
					  )
				   ),
				   'posts_per_page'   => 1,	
				   'meta_key'         => 'sa_smartadv_inj_tt',
				   'meta_value'       => 1,
				   'meta_compare'     => '=',
				   'orderby'          => 'rand',		
				   'post_status'      => 'publish'
				);
				
				$advertises = get_posts( $args );
				
				if($advertises) {
					
					// Replace of keys matched
					$content = preg_replace("/".$key->name."/i", "<span class='tooltip' data-tag='".$key->slug."'>\$0</span>", $content);
					
					$advertises_content = sa_adv_content($advertises[0]->ID, $advertises[0]->post_title);
					
					if($tooltips_activation == 1){ 
						$styling = get_post_meta( get_the_id(), 'sa_tt_styling', true ); 
						if(get_post_meta( get_the_id(), 'sa_tt_styling_shadow', true ) == 1) { $styling_shadow = 'qtip-shadow'; }else{ $styling_shadow = ''; }
						if(get_post_meta( get_the_id(), 'sa_tt_styling_rounded', true ) == 1) { $styling_rounded = 'qtip-rounded'; }else{ $styling_rounded = ''; }
					}else{ 
						$styling = get_option('sa_opt_tt_styling'); 
						if(get_option( 'sa_opt_tt_shadow' ) == 1) { $styling_shadow = 'qtip-shadow'; }else{ $styling_shadow = ''; }
						if(get_option( 'sa_opt_tt_border' ) == 1) { $styling_rounded = 'qtip-rounded'; }else{ $styling_rounded = ''; }
					}
					
					
					
					
					$styling_addons = $styling_shadow.' '.$styling_rounded;
					
					$advertises_html .= '<span class="'.$key->slug.'" style="display:none;" data-title="'.$advertises[0]->post_title.'" data-styling="'.$styling.' '.$styling_addons.'">'.$advertises_content.'</span>';
					
				} // End IF advertises 
			
			} // End key exixting
			
		}
		
		$content .= $advertises_html;
	
	}
	
	
	return $content;
	
}


// Popup Injection
add_filter('the_content','sa_add_popup_to_content');

function sa_add_popup_to_content($content) {
	
	$popup_activation = get_post_meta( get_the_id(), 'sa_pp_activation', true );
	
	if($popup_activation == 1 || $popup_activation == 2 ) { // Popup Enabled
		
		// Check Global Activation
		if($popup_activation == 2 && get_option('sa_opt_pp_activation') != 'ON') {
			return $content;
		}
		
		if($popup_activation == 2 && get_option('sa_opt_pp_activation') == 'ON') {
			
			$popup_source = get_option( 'sa_opt_pp_source' ); 
			$popup_expiration = get_option( 'sa_opt_pp_expires' );
			$popup_animation = get_option( 'sa_opt_pp_animation' );
			$popup_speed = get_option( 'sa_opt_pp_speed' );
			
			// Popup Source switch
			switch ( $popup_source ) {
				
				case 'density':
				$advertises_html_pop = sa_pp_density($content, $popup_expiration, $popup_animation, $popup_speed);
				break;
				
				case 'random':
				$advertises_html_pop = sa_pp_random($content, $popup_expiration, $popup_animation, $popup_speed);
				break;
				
				case 'category':
				$category_id = get_option( 'sa_opt_pp_cat' );
				$advertises_html_pop = sa_pp_category($content, $category_id, $popup_expiration, $popup_animation, $popup_speed);
				break;
				
				case 'single':
				$adv_id = get_option( 'sa_opt_pp_single' );
				$advertises_html_pop = sa_pp_single($content, $adv_id, $popup_expiration, $popup_animation, $popup_speed);
				break;
			
			} // Popup Source switch
			
		}else{
			
			$popup_source = get_post_meta( get_the_id(), 'sa_pp_source', true );
			$popup_expiration = get_post_meta( get_the_id(), 'sa_pp_expires', true );
			$popup_animation = get_post_meta( get_the_id(), 'sa_pp_animation', true );
			$popup_speed = get_post_meta( get_the_id(), 'sa_pp_speed', true );
			
			// Popup Source switch
			switch ( $popup_source ) {
				
				case 'density':
				$advertises_html_pop = sa_pp_density($content, $popup_expiration, $popup_animation, $popup_speed);
				break;
				
				case 'random':
				$advertises_html_pop = sa_pp_random($content, $popup_expiration, $popup_animation, $popup_speed);
				break;
				
				case 'category':
				$category_id = get_post_meta( get_the_id(), 'sa_pp_category', true );
				$advertises_html_pop = sa_pp_category($content, $category_id, $popup_expiration, $popup_animation, $popup_speed);
				break;
				
				case 'single':
				$adv_id = get_post_meta( get_the_id(), 'sa_pp_single', true );
				$advertises_html_pop = sa_pp_single($content, $adv_id, $popup_expiration, $popup_animation, $popup_speed);
				break;
			
			} // Popup Source switch
			
		} // IF GLOBAL
		
	} // Popup Enabled
	
	
	// Add the ADV to the content	
	if(!empty($advertises_html_pop)) {
		return $content.$advertises_html_pop;
	}else{
		return $content;
	}
	
}


// POPUP FUNCTIONS //

// Density
function sa_pp_density($content, $popup_expiration, $popup_animation, $popup_speed) {
	
	$advertises_html_pop = ''; 
			
			$ar_keys = get_terms('advkeys');
			
			$cleaned_content = strip_tags($content);
			
			$ar_final = array();
			
			foreach ($ar_keys as $key) {
				
				$key_count = preg_match_all("/".$key->name."/i", $cleaned_content);

				if ( $key_count > 0 ) {
		
					$ar_final[$key_count] = $key->slug;
					
				}
				
			}
			
			
			krsort($ar_final);
			
			$ar_final = (array_values($ar_final));
			
			
			foreach ($ar_final as $final_term) {
			
				if (isset($final_term)) {
	
				// Query ADVs by tag
				$args_pop = array(
				   'post_type' => 'advertises',
				   'tax_query' => array(
					  array(
						 'taxonomy' => 'advkeys', 
						 'field' => 'slug',
						 'terms' => $final_term
					  )
				   ),
				   'posts_per_page'   => 1,	
				   'meta_key'         => 'sa_smartadv_inj_pp',
				   'meta_value'       => 1,
				   'meta_compare'     => '=',
				   'orderby'          => 'rand',		
				   'post_status'      => 'publish'
				);
				
				$advertises_pop = get_posts( $args_pop );
				
				// Check if at least an adv exists
				if ($advertises_pop) { break; }
		
				} // ISSET $final_term
			
			} // FOREACH $ar_final
			
				
			if (isset($advertises_pop[0])) {
					
				$advertises_content = sa_adv_content($advertises_pop[0]->ID, $advertises_pop[0]->post_title);
					
				return $advertises_html_pop = '
					<div id="myModal" class="reveal-modal" data-expiration="'.$popup_expiration.'" data-animation="'.$popup_animation.'" data-speed="'.$popup_speed.'">
						 <h1>'.$advertises_pop[0]->post_title.'</h1>
						 <p>'.$advertises_content.'</p>
						 <a class="close-reveal-modal">&#215;</a>
					</div>';
					
			} // IF isset $advertises_pop
			
		
			
}


// Random
function sa_pp_random($content, $popup_expiration, $popup_animation, $popup_speed) { 

	// Query ADVs by tag
	$args_pop = array(
			 'post_type' => 'advertises',
			 'posts_per_page'   => 1,
			 'meta_key'         => 'sa_smartadv_inj_pp',
			 'meta_value'       => 1,
			 'meta_compare'     => '=',
			 'orderby'          => 'rand',		
			 'post_status'      => 'publish' 
	);
	
	$advertises_pop = get_posts( $args_pop );
	
	if (isset($advertises_pop[0])) {
		
		$advertises_content = sa_adv_content($advertises_pop[0]->ID, $advertises_pop[0]->post_title);
		
		return $advertises_html_pop = '
			<div id="myModal" class="reveal-modal" data-expiration="'.$popup_expiration.'" data-animation="'.$popup_animation.'" data-speed="'.$popup_speed.'">
					 <h1>'.$advertises_pop[0]->post_title.'</h1>
					 <p>'.$advertises_content.'</p>
					 <a class="close-reveal-modal">&#215;</a>
			</div>';
	} // IF isset $advertises_pop[0]

}


// Category
function sa_pp_category($content, $category_id, $popup_expiration, $popup_animation, $popup_speed) { 
	
	// Category Slug
	$cat_obj = get_term( $category_id, 'advcategories' );
	
	// Query ADVs by category
	if(isset($cat_obj)){
		
		$args_pop = array(
				 'post_type' => 'advertises',
				 'tax_query' => array(
					  array(
						 'taxonomy' => 'advcategories', 
						 'field' => 'slug',
						 'terms' => array($cat_obj->slug)
					  )
				  ),
				 'posts_per_page'   => 1,	
				 'meta_key'         => 'sa_smartadv_inj_pp',
			     'meta_value'       => 1,
			     'meta_compare'     => '=',
				 'orderby'          => 'rand',		
				 'post_status'      => 'publish' 
		);
		
		
		$advertises_pop = get_posts( $args_pop );
	
	}
	
	if (isset($advertises_pop[0])) {
		
		$advertises_content = sa_adv_content($advertises_pop[0]->ID, $advertises_pop[0]->post_title);
		
		return $advertises_html_pop = '
			<div id="myModal" class="reveal-modal" data-expiration="'.$popup_expiration.'" data-animation="'.$popup_animation.'" data-speed="'.$popup_speed.'">
					 <h1>'.$advertises_pop[0]->post_title.'</h1>
					 <p>'.$advertises_content.'</p>
					 <a class="close-reveal-modal">&#215;</a>
			</div>';
	} // IF isset $advertises_pop[0]

}


// Single
function sa_pp_single($content, $adv_id, $popup_expiration, $popup_animation, $popup_speed) { 
		
	// Query ADV by ID
	$advertises_pop = get_post( $adv_id );
	$advertises_pop_inj =  get_post_meta( $adv_id, 'sa_smartadv_inj_pp', true );
	
	if (isset($advertises_pop) && $advertises_pop->post_status == 'publish' && $advertises_pop_inj == 1 ) {
		
		$advertises_content = sa_adv_content($advertises_pop->ID, $advertises_pop->post_title);
		
		return $advertises_html_pop = '
				<div id="myModal" class="reveal-modal" data-expiration="'.$popup_expiration.'" data-animation="'.$popup_animation.'" data-speed="'.$popup_speed.'">
					 <h1>'.$advertises_pop->post_title.'</h1>
					 <p>'.$advertises_content.'</p>
					 <a class="close-reveal-modal">&#215;</a>
				</div>';
	} // IF isset $advertises_pop[0]

}


// Advertise Content

function sa_adv_content($id, $title) {
	
	$advertise_type = get_post_meta( $id, 'sa_smartadv_type', true );
					
	$advertise_content = '';
					
	switch ($advertise_type) {
						
		case 'html':
		$advertise_content = get_post_meta( $id, 'sa_smartadv_html', true );
		break;
						
		case 'text':
		$advertise_content = wp_strip_all_tags(get_post_meta( $id, 'sa_smartadv_text', true ));
		break;
						
		case 'code':
		$advertise_content = get_post_meta( $id, 'sa_smartadv_code', true );
		break;
						
		case 'media':
						
		$adv_image = wp_get_attachment_image(get_post_meta( $id, 'sa_smartadv_media_image', true ), 'full');
		$adv_url = get_post_meta( $id, 'sa_smartadv_media_url', true );
		$adv_target = get_post_meta( $id, 'sa_smartadv_media_target', true );
						
		$advertise_content = '<a href="'.$adv_url.'" target="'.$adv_target.'" title="'.$title.'">'.$adv_image.'</a>';
		break;
					
	}
	
	return $advertise_content;
	
}