<?php
/*
File: inc/metaboxes.php
Description: Plugin metaboxes
Plugin: Smart Adv
Author: Alessio Marzo
*/


// Include meta framework

require_once( SA_DIR.'/inc/Custom-Meta-Boxes-master/custom-meta-boxes.php' ); 


// BASIC META OPTIONS //

add_filter( 'sacmb_meta_boxes', 'sa_meta_options' );

function sa_meta_options( array $meta_boxes ) {
	
	// Select all post types removing advertises
	$args = array(
	   'public'   => true,
	);

	$all_types = get_post_types($args, 'names', 'and');
	
	$sel_types = array();
	
	foreach ($all_types as $type) {
		if ($type != 'advertises' && $type != 'attachment') { $sel_types[] = $type; }
	}

	$qtip_presets = array(
		''               => 'Default yellow style',
		'qtip-light'     => 'Light coloured style',
		'qtip-dark'      => 'Alternative dark style',
		'qtip-cream'     => 'Cream-esque style, similar to the default',
		'qtip-red'       => 'Alert-ful red style',
		'qtip-green'     => 'Positive green style',
		'qtip-blue'      => 'Informative blue style',
		'qtip-bootstrap' => 'Twitter Bootstrap style',
		'qtip-youtube'   => 'Google\'s new YouTube style',
		'qtip-tipsy'     => 'Minimalist Tipsy style',
		'qtip-tipped'    => 'Tipped libraries "Blue" style',
		'qtip-jtools'    => 'jTools tooltip style',
		'qtip-cluetip'   => 'Good ole\' ClueTip style'
	);
	
	// All Fields
	$smartadv_fields = array(
	
		array( 'id' => 'sa_tt_title', 'type' => 'title', 'name' => 'Tooltips', 'desc' => __('Inject your advertises as tooltips in the content', SA_PLG_NAME), 'cols' => 3 ),
		
		array( 'id' => 'sa_tt_activation', 'name' => '', 'type' => 'radio', 'options' => array( '2' => 'Global', '0' => 'OFF', '1' => 'ON' ), 'default' => '2', 'cols' => 3 ),
		
		array( 'id' => 'sa_pp_title', 'type' => 'title', 'name' => 'Popups', 'desc' => __('Inject your advertises as a popup in the page', SA_PLG_NAME), 'cols' => 3  ),
		
		array( 'id' => 'sa_pp_activation', 'name' => '', 'type' => 'radio', 'options' => array( '2' => 'Global', '0' => 'OFF', '1' => 'ON' ), 'default' => '0', 'cols' => 3  ),
		
		array( 'id' => 'sa_tt_styling', 'name' => 'Styling', 'type' => 'select', 'options' => $qtip_presets, 'default' => '', 'cols' => 2 ),
		
		array( 'id' => 'sa_tt_styling_rounded', 'name' => 'CSS3 Rounded Border', 'type' => 'checkbox', 'cols' => 2 ),
		
		array( 'id' => 'sa_tt_styling_shadow', 'name' => 'CSS3 Shadow', 'type' => 'checkbox', 'cols' => 2 ),
		
		array( 'id' => 'sa_pp_expires', 'name' => 'Expiration (seconds)', 'type' => 'text_small', 'default' => '3600', 'cols' => 2 ),
		
		array( 'id' => 'sa_pp_animation', 'name' => 'Animation', 'type' => 'select', 'options' => array('fadeAndPop' => 'Fade and Pop', 'fade' => 'Fade', 'none' => 'None'), 'default' => 'fadeAndPop', 'cols' => 2 ),
		
		array( 'id' => 'sa_pp_speed', 'name' => 'Speed (milliseconds)', 'type' => 'text_small', 'default' => '300', 'cols' => 2 ),
		
		array( 'id' => 'sa_tt_source', 'name' => 'Source', 'type' => 'desc', 'desc' => __('Tooltips will be shown searching the advertises\'s <b style="color:#288DBB;">keys</b> in the content so make sure you\'ve entered some tag for your advertises!', SA_PLG_NAME), 'cols' => 6 ),
		
		array( 'id' => 'sa_pp_source', 'name' => 'Source', 'type' => 'select', 'options' => array('density' => 'Key Density', 'random' => 'Random ADV from All', 'category' => 'Random ADV from Category', 'single' => 'Specific ADV'), 'default' => 'density', 'cols' => 3 ),
		
		array( 'id' => 'sa_pp_source_desc', 'name' => '', 'type' => 'desc', 'desc' => __('<h4><br>Select a source for your popup</h4>', SA_PLG_NAME), 'cols' => 3 ),
		
		array( 'id' => 'sa_tt_spacer1', 'name' => '', 'type' => 'desc', 'cols' => 6 ),
		
		array( 'id' => 'sa_pp_density', 'name' => 'Key Density', 'type' => 'desc', 'desc' => __('Our density calculator will search all ADV\'s keys in the content and will popup the ADV that has the tag with higher density in the content.', SA_PLG_NAME), 'cols' => 6 ),
		
		array( 'id' => 'sa_tt_spacer1', 'name' => '', 'type' => 'desc', 'cols' => 6 ),
		
		array( 'id' => 'sa_pp_random', 'name' => 'Random ADV from All', 'type' => 'desc', 'desc' => __('Plugin will popup a random ADV from your ADVs list.', SA_PLG_NAME), 'cols' => 6 ),
		
		array( 'id' => 'sa_tt_spacer2', 'name' => '', 'type' => 'desc', 'cols' => 6 ),
		
		array( 'id' => 'sa_pp_category', 'name' => 'Random ADV from Category', 'type' => 'taxonomy_select', 'taxonomy' => 'advcategories',  'cols' => 3 ),
		
		array( 'id' => 'sa_pp_category_desc', 'name' => '', 'type' => 'desc', 'desc' => __('<h4><br>Select a category of ADVs</h4>', SA_PLG_NAME), 'cols' => 3 ),
		
		array( 'id' => 'sa_tt_spacer3', 'name' => '', 'type' => 'desc', 'cols' => 6 ),
		
		array( 'id' => 'sa_pp_single', 'name' => 'Specific ADV', 'type' => 'post_select', 'use_ajax' => false, 'query' => array( 'post_type'=> 'advertises', 'posts_per_page' => -1, 'post_status'=>'publish', 'meta_key' => 'sa_smartadv_inj_pp', 'meta_value' => '1', 'meta_compare' => '==' ),  'cols' => 3 ),
		
		array( 'id' => 'sa_pp_single_desc', 'name' => '', 'type' => 'desc', 'desc' => __('<h4><br>Select your ADV</h4>', SA_PLG_NAME), 'cols' => 3 )
	
	);
		
	

	$meta_boxes[] = array(
		'title' => 'Smart ADV Options',
		'pages' => $sel_types,
		'fields' => $smartadv_fields,
		'context'  => 'normal'
	);


	return $meta_boxes;
	
}



// SMARTADV META OPTIONS //

add_filter( 'sacmb_meta_boxes', 'sa_smartadv_meta_options' );

function sa_smartadv_meta_options( array $meta_boxes ) {
	

	$qtip_presets = array(
		''               => 'Default yellow style',
		'qtip-light'     => 'Light coloured style',
		'qtip-dark'      => 'Alternative dark style',
		'qtip-cream'     => 'Cream-esque style, similar to the default',
		'qtip-red'       => 'Alert-ful red style',
		'qtip-green'     => 'Positive green style',
		'qtip-blue'      => 'Informative blue style',
		'qtip-bootstrap' => 'Twitter Bootstrap style',
		'qtip-youtube'   => 'Google\'s new YouTube style',
		'qtip-tipsy'     => 'Minimalist Tipsy style',
		'qtip-tipped'    => 'Tipped libraries "Blue" style',
		'qtip-jtools'    => 'jTools tooltip style',
		'qtip-cluetip'   => 'Good ole\' ClueTip style'
	);
	
	// All Fields
	$smartadv_fields = array(
	
		array( 'id' => 'sa_smartadv_type', 'type' => 'select', 'name' => 'Type', 'options' => array('html' => 'HTML Content', 'text' => 'TEXT Content', 'code' => 'Custom CODE', 'media' => 'Media Image'), 'default' => 'html', 'desc' => __('Select the type for your Advertise', SA_PLG_NAME), 'cols' => 2 ),

		array( 'id' => 'sa_smartadv_html', 'type' => 'wysiwyg', 'name' => 'HTML Content', 'cols' => 10 ),
		
		array( 'id' => 'sa_smartadv_text', 'type' => 'textarea', 'name' => 'TEXT Content', 'desc' => __('All tags and codes will be stripped', SA_PLG_NAME), 'cols' => 10 ),
		
		array( 'id' => 'sa_smartadv_code', 'type' => 'textarea_code', 'name' => 'Custom CODE', 'desc' => __('Use this field to attach external code like Youtube embed code or JS banners', SA_PLG_NAME), 'cols' => 10 ),
		
		array( 'id' => 'sa_smartadv_media_image', 'type' => 'image', 'name' => 'Upload Image', 'size' => 'height=100&width=100&crop=1', 'desc' => __('Upload your image here', SA_PLG_NAME), 'cols' => 2 ),
		
		array( 'id' => 'sa_smartadv_media_url', 'type' => 'text_url', 'name' => 'Link URL', 'desc' => __('Fill the URL for the link to attach to the image', SA_PLG_NAME), 'cols' => 6 ),
		
		array( 'id' => 'sa_smartadv_media_target', 'type' => 'select', 'name' => 'Target', 'options' => array('_blank' => 'New Window/Tab', '_self' => 'Same Window/Tab'), 'desc' => __('Select the target for the Link', SA_PLG_NAME), 'cols' => 2 ),
		
		array( 'id' => 'sa_smartadv_spacer', 'name' => '', 'type' => 'desc', 'cols' => 12 ),
		
		array( 'id' => 'sa_smartadv_inj_tt', 'type' => 'radio', 'name' => 'Enable for Tootlips', 'options' => array(0 => 'OFF', 1 => 'ON'), 'default' => 1, 'desc' => __('Allow this ADV to be displayed in the Tooltips', SA_PLG_NAME), 'cols' => 6 ),
		
		array( 'id' => 'sa_smartadv_inj_pp', 'type' => 'radio', 'name' => 'Enable for Popups', 'options' => array(0 => 'OFF', 1 => 'ON'), 'default' => 1, 'desc' => __('Allow this ADV to be displayed in the Popups', SA_PLG_NAME), 'cols' => 6 )
		
	);
		
	

	$meta_boxes[] = array(
		'title' => 'Advertise Setup',
		'pages' => 'advertises',
		'fields' => $smartadv_fields,
		'context'  => 'normal'
	);


	return $meta_boxes;
	
}

