<?php
/*
File: inc/posttypes/advertises.php
Description: Register Advertises Post Type
Plugin: Smart Adv
Author: Alessio Marzo
*/


// Post Type Registration
add_action( 'init', 'sa_advertises_register_posttype' );

function sa_advertises_register_posttype() {

	$labels = array(
		'name'               => __('Advertises', SA_PLG_NAME),
		'singular_name'      => __('Advertise', SA_PLG_NAME),
		'add_new'            => __('Add New', SA_PLG_NAME),
		'add_new_item'       => __('Add New Advertise', SA_PLG_NAME),
		'edit_item'          => __('Edit Advertise', SA_PLG_NAME),
		'new_item'           => __('New Advertise', SA_PLG_NAME),
		'all_items'          => __('All Advertises', SA_PLG_NAME),
		'view_item'          => __('View Advertise', SA_PLG_NAME),
		'search_items'       => __('Search Advertises', SA_PLG_NAME),
		'not_found'          => __('No advertises found', SA_PLG_NAME),
		'not_found_in_trash' => __('No advertises found in trash', SA_PLG_NAME),
		'parent_item_colon'  => '',
		'menu_name'          => __('Smart ADV', SA_PLG_NAME)
	  );
	
	  $args = array(
		'labels'             => $labels,
		'public'             => true,
		'publicly_queryable' => true,
		'show_ui'            => true,
		'show_in_menu'       => true,
		'query_var'          => true,
		'rewrite'            => array( 'slug' => 'advertises' ),
		'capability_type'    => 'post',
		'has_archive'        => true,
		'hierarchical'       => false,
		'menu_position'      => null,
		'menu_icon'          => SA_URL .'assets/img/main_icon.png', // 16px16
		'supports'           => array( 'title' )
	  );
	
	  register_post_type( 'advertises', $args );

}



// Taxonomy Registration
add_action( 'init', 'sa_advertises_register_taxonomy', 0 );

function sa_advertises_register_taxonomy() {
	
	// Add new taxonomy, make it hierarchical (like categories)
	$labels = array(
		'name'              => __( 'Categories', SA_PLG_NAME),
		'singular_name'     => __( 'Category', SA_PLG_NAME),
		'search_items'      => __( 'Search Categories', SA_PLG_NAME),
		'all_items'         => __( 'All Categories', SA_PLG_NAME),
		'parent_item'       => __( 'Parent Category', SA_PLG_NAME),
		'parent_item_colon' => __( 'Parent Category:', SA_PLG_NAME),
		'edit_item'         => __( 'Edit Category', SA_PLG_NAME),
		'update_item'       => __( 'Update Category', SA_PLG_NAME),
		'add_new_item'      => __( 'Add New Category', SA_PLG_NAME),
		'new_item_name'     => __( 'New Category Name', SA_PLG_NAME),
		'menu_name'         => __( 'Categories', SA_PLG_NAME),
	);

	$args = array(
		'hierarchical'      => true,
		'labels'            => $labels,
		'show_ui'           => true,
		'show_admin_column' => true,
		'query_var'         => true,
		'rewrite'           => array( 'slug' => 'advcategories' ),
	);

	register_taxonomy( 'advcategories', array( 'advertises' ), $args );
	

	// Add new taxonomy, NOT hierarchical (like tags)
	$labels = array(
		'name'                       => __( 'Keys', SA_PLG_NAME),
		'singular_name'              => __( 'Key', SA_PLG_NAME),
		'search_items'               => __( 'Search Keys', SA_PLG_NAME),
		'popular_items'              => __( 'Popular Keys', SA_PLG_NAME),
		'all_items'                  => __( 'All Keys', SA_PLG_NAME),
		'parent_item'                => null,
		'parent_item_colon'          => null,
		'edit_item'                  => __( 'Edit Key', SA_PLG_NAME),
		'update_item'                => __( 'Update Key', SA_PLG_NAME),
		'add_new_item'               => __( 'Add New Key', SA_PLG_NAME),
		'new_item_name'              => __( 'New Key Name', SA_PLG_NAME),
		'separate_items_with_commas' => __( 'Separate keys with commas<br><br><b style="font-style:normal;">Keys are very important for the displaying in the pages</b>', SA_PLG_NAME),
		'add_or_remove_items'        => __( 'Add or remove keys', SA_PLG_NAME),
		'choose_from_most_used'      => __( 'Choose from the most used keys', SA_PLG_NAME),
		'not_found'                  => __( 'No keys found.', SA_PLG_NAME),
		'menu_name'                  => __( 'Keys', SA_PLG_NAME),
	);

	$args = array(
		'hierarchical'          => false,
		'labels'                => $labels,
		'show_ui'               => true,
		'show_admin_column'     => true,
		'update_count_callback' => '_update_post_term_count',
		'query_var'             => true,
		'rewrite'               => array( 'slug' => 'advkeys' ),
	);

	register_taxonomy( 'advkeys', 'advertises', $args );
	
}


// Add TT Column //

// Register the column
add_filter( 'manage_edit-advertises_columns', 'sa_tt_column_register' );

function sa_tt_column_register( $columns ) {
	$columns['tooltips'] = __( 'Tooltips', SA_PLG_NAME );
	return $columns;
}

// Display the column content
add_action( 'manage_advertises_posts_custom_column', 'sa_tt_column_display', 10, 2 );

function sa_tt_column_display( $column_name, $post_id ) {
	if ( 'tooltips' != $column_name )
		return;
 
	$tt = get_post_meta($post_id, 'sa_smartadv_inj_tt', true);
	
	if($tt == 1){
		echo '<img src="'.SA_URL.'assets/img/eye-open.png" class="inj_tt">';
	}else{
		echo '<img src="'.SA_URL.'assets/img/eye-blocked.png" class="inj_tt">';
	}
	
}


// Add PP Column //

// Register the column
add_filter( 'manage_edit-advertises_columns', 'sa_pp_column_register' );

function sa_pp_column_register( $columns ) {
	$columns['popups'] = __( 'Popups', SA_PLG_NAME );
	return $columns;
}

// Display the column content
add_action( 'manage_advertises_posts_custom_column', 'sa_pp_column_display', 10, 2 );

function sa_pp_column_display( $column_name, $post_id ) {
	if ( 'popups' != $column_name )
		return;
 
	$pp = get_post_meta($post_id, 'sa_smartadv_inj_pp', true);
	
	if($pp == 1){
		echo '<img src="'.SA_URL.'assets/img/eye-open.png" class="inj_tt">';
	}else{
		echo '<img src="'.SA_URL.'assets/img/eye-blocked.png" class="inj_tt">';
	}
}



// Category filtering
add_action('restrict_manage_posts','sa_filter_by_category');

function sa_filter_by_category() {
    global $typenow;
    global $wp_query;
	
    if ($typenow=='advertises') {
        $taxonomy = 'advcategories';
        $taxonomy_obj = get_taxonomy($taxonomy);
		if(!empty($wp_query->query_vars['term'])) {$cat_sel = $_GET[$taxonomy_obj->query_var]; }else{$cat_sel = '0';}
        wp_dropdown_categories(array(
            'show_option_all' =>  __("All Categories", SA_PLG_NAME),
            'taxonomy'        =>  $taxonomy,
            'name'            =>  'advcategories',
            'orderby'         =>  'name',
			'selected'        =>  $cat_sel,
            'hierarchical'    =>  true,
            'depth'           =>  3,
            'show_count'      =>  true,
            'hide_empty'      =>  true, 
        ));
    }
}

add_filter('parse_query','sa_convert_advertises_category_id_to_taxonomy_term_in_query');

function sa_convert_advertises_category_id_to_taxonomy_term_in_query($query) {
    global $pagenow;
    $qv = &$query->query_vars;
    if ($pagenow=='edit.php' && isset($qv['advcategories']) && is_numeric($qv['advcategories'])) {
        $term = get_term_by('id',$qv['advcategories'],'advcategories');
        $qv['advcategories'] = ($term ? $term->slug : '');
    }
}


// Keys filtering
add_action('restrict_manage_posts','sa_filter_by_keys');

function sa_filter_by_keys() {
    global $typenow;
    global $wp_query;
	
    if ($typenow=='advertises') {
        $taxonomy = 'advkeys';
        $taxonomy_obj = get_taxonomy($taxonomy);
		if(!empty($wp_query->query_vars['term'])) {$cat_sel = $_GET[$taxonomy_obj->query_var]; }else{$cat_sel = '0';}
        wp_dropdown_categories(array(
            'show_option_all' =>  __("All Keys", SA_PLG_NAME),
            'taxonomy'        =>  $taxonomy,
            'name'            =>  'advkeys',
            'orderby'         =>  'name',
			'selected'        =>  $cat_sel,
            'hierarchical'    =>  true,
            'depth'           =>  3,
            'show_count'      =>  true,
            'hide_empty'      =>  true, 
        ));
    }
}

add_filter('parse_query','sa_convert_advertises_key_id_to_taxonomy_term_in_query');

function sa_convert_advertises_key_id_to_taxonomy_term_in_query($query) {
    global $pagenow;
    $qv = &$query->query_vars;
    if ($pagenow=='edit.php' && isset($qv['advkeys']) && is_numeric($qv['advkeys'])) {
        $term = get_term_by('id',$qv['advkeys'],'advkeys');
        $qv['advkeys'] = ($term ? $term->slug : '');
    }
}


// Post Type custom messages
add_filter( 'post_updated_messages', 'sa_advertises_custom_messages' );

function sa_advertises_custom_messages( $messages ) {
	
  global $post, $post_ID;

  $messages['advertises'] = array(
    0 => '', // Unused. Messages start at index 1.
    1 => sprintf( __('Advertise updated. <a href="%s">View Advertise</a>', SA_PLG_NAME), esc_url( get_permalink($post_ID) ) ),
    2 => __('Custom field updated.', SA_PLG_NAME),
    3 => __('Custom field deleted.', SA_PLG_NAME),
    4 => __('Advertise updated.', SA_PLG_NAME),
    /* translators: %s: date and time of the revision */
    5 => isset($_GET['revision']) ? sprintf( __('Advertise restored to revision from %s', SA_PLG_NAME), wp_post_revision_title( (int) $_GET['revision'], false ) ) : false,
    6 => sprintf( __('Advertise published. <a href="%s">View Advertise</a>', SA_PLG_NAME), esc_url( get_permalink($post_ID) ) ),
    7 => __('Advertise saved.', SA_PLG_NAME),
    8 => sprintf( __('Advertise submitted. <a target="_blank" href="%s">Preview Advertise</a>', SA_PLG_NAME), esc_url( add_query_arg( 'preview', 'true', get_permalink($post_ID) ) ) ),
    9 => sprintf( __('Advertise scheduled for: <strong>%1$s</strong>. <a target="_blank" href="%2$s">Preview Advertise</a>', SA_PLG_NAME),
      // translators: Publish box date format, see http://php.net/date
      date_i18n( __( 'M j, Y @ G:i', SA_PLG_NAME ), strtotime( $post->post_date ) ), esc_url( get_permalink($post_ID) ) ),
    10 => sprintf( __('Advertise draft updated. <a target="_blank" href="%s">Preview Advertise</a>', SA_PLG_NAME), esc_url( add_query_arg( 'preview', 'true', get_permalink($post_ID) ) ) ),
  );

  return $messages;
  
}